@@ -36,11 +36,10 @@ TableEntry = get_class('cms.blocks.entries', 'TableEntry')
 NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
 AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
-
+PortfoliosEntry = get_class('cms.blocks.entries', 'PortfoliosEntry')
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
 SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
 
-
 #  Models
 Menu = get_model('cms', 'Menu')
 IconSnippet = get_model('cms', 'IconSnippet')
@@ -133,6 +132,7 @@ class AGenericPage(Page):
         ('accordion', AccordionEntry()),
         ('numbers', NumbersEntry()),
         ('form', FormEntry()),
+        ('portfolios', PortfoliosEntry())
     ], blank=True)
 
     content_panels = [
@@ -208,18 +208,6 @@ class AGenericPage(Page):
             return (urls[0], urls[1], '/amp' + urls[2])
         return urls
 
-    def render_baked_file(self, request, path_file):
-        index = 'index.html' if request.user_agent.is_pc else 'index-mobile.html'
-        if amp_mode_active():
-            index = index.replace('.html', '-amp.html')
-            path_file = path_file.replace('/amp', '')
-        with open(path_file + index, "rb") as fd:
-            compressed = fd.read()
-            response = HttpResponse(compressed)
-            response['Content-Encoding'] = 'gzip'
-            response['Content-Length'] = str(len(compressed))
-            return response
-
     def get_template(self, request, *args, **kwargs):
         return "%s/%s.html" % (
             constants.PAGES_TEMPLATES_PATH,
